@@ -9,7 +9,7 @@ from ase.io import read
 from TB2J.utils import auto_assign_basis_name
 from TB2J.io_exchange import SpinIO
 from tqdm import tqdm
-from p_tqdm import p_map
+from TB2J.external import p_map
 from TB2J.contour import Contour
 from TB2J.utils import simpson_nonuniform, trapezoidal_nonuniform
 from TB2J.orbmap import map_orbs_matrix
@@ -18,6 +18,7 @@ import pickle
 
 
 class Exchange():
+
     def __init__(
             self,
             tbmodels,
@@ -29,7 +30,7 @@ class Exchange():
             kmesh=[4, 4, 4],
             emin=-15,  # integration lower bound, relative to fermi energy
             # integration upper bound. Should be 0 (fermi energy). But DFT codes define Fermi energy in various ways.
-            emax=0.05,
+        emax=0.05,
             nz=100,
             # the delta in the (i delta) in green's function to prevent divergence
             height=0.5,
@@ -42,8 +43,7 @@ class Exchange():
             use_cache=False,
             np=1,
             description='',
-            orb_decomposition=False
-    ):
+            orb_decomposition=False):
 
         self.atoms = atoms
         self.efermi = efermi
@@ -197,7 +197,8 @@ class Exchange():
         for iatom in self.ind_mag_atoms:
             if iatom not in self.orb_dict:
                 raise ValueError(
-                    f"""Cannot find any orbital for atom {iatom}, which is supposed to be magnetic. Please check the Wannier functions.""")
+                    f"""Cannot find any orbital for atom {iatom}, which is supposed to be magnetic. Please check the Wannier functions."""
+                )
 
         self._spin_dict = {}
         self._atom_dict = {}
@@ -214,7 +215,8 @@ class Exchange():
         if self.backend_name == "SIESTA":
             syms = self.atoms.get_chemical_symbols()
             for iatom, orbs in self.labels.items():
-                if (self.include_orbs is not None) and syms[iatom] in self.include_orbs:
+                if (self.include_orbs
+                        is not None) and syms[iatom] in self.include_orbs:
                     mmat, reduced_orbs = map_orbs_matrix(
                         orbs,
                         spinor=not (self._is_collinear),
@@ -227,11 +229,11 @@ class Exchange():
 
                 self.mmats[iatom] = mmat
                 self.orbital_names[iatom] = reduced_orbs
-                self.norb_reduced[iatom] = len(reduced_orbs)//2
+                self.norb_reduced[iatom] = len(reduced_orbs) // 2
         else:
             self.orbital_names = self.labels
             for iatom, orbs in self.labels.items():
-                self.norb_reduced[iatom] = len(orbs)//2
+                self.norb_reduced[iatom] = len(orbs) // 2
 
     def ispin(self, iatom):
         return self._spin_dict[iatom]
@@ -393,8 +395,8 @@ class ExchangeNCL(Exchange):
                 for b in range(4):
                     pjGji = self.get_P_iatom(jatom) @ Gji_Ixyz[b]
                     torb[a, b] = self.simplify_orbital_contributions(
-                        np.einsum('ij, ji -> ij', piGij, pjGji)/np.pi,
-                        iatom, jatom)
+                        np.einsum('ij, ji -> ij', piGij, pjGji) / np.pi, iatom,
+                        jatom)
                     tmp[a, b] = np.sum(torb[a, b])
 
         else:
@@ -403,7 +405,7 @@ class ExchangeNCL(Exchange):
                     jatom)
                 for b in range(4):
                     AijRab = pGp @ Gji_Ixyz[b]
-                    tmp[a, b] = np.trace(AijRab)/np.pi
+                    tmp[a, b] = np.trace(AijRab) / np.pi
             torb = None
         return tmp, torb
 
@@ -451,8 +453,8 @@ class ExchangeNCL(Exchange):
                 Ja = np.zeros((3, 3, ni, nj), dtype=float)
                 for i in range(3):
                     for j in range(3):
-                        Ja[i, j] = np.imag(
-                            val[i + 1, j + 1] + valm[i + 1, j + 1])
+                        Ja[i,
+                           j] = np.imag(val[i + 1, j + 1] + valm[i + 1, j + 1])
                 # DMI
 
                 Dtmp = np.zeros((3, ni, nj), dtype=float)
@@ -637,8 +639,8 @@ class ExchangeNCL(Exchange):
                 f = AijRs[(R, iatom, jatom)]
                 self.A_ijR[(R, iatom, jatom)] = integrate(self.contour.path, f)
                 if self.orb_decomposition:
-                    self.A_ijR_orb[(R, iatom, jatom)] = integrate(self.contour.path,
-                                                                  AijRs_orb[(R, iatom, jatom)])
+                    self.A_ijR_orb[(R, iatom, jatom)] = integrate(
+                        self.contour.path, AijRs_orb[(R, iatom, jatom)])
 
     def get_AijR_rhoR(self, e):
         GR, rhoR = self.G.get_GR(self.short_Rlist, energy=e, get_rho=True)
@@ -666,10 +668,11 @@ class ExchangeNCL(Exchange):
             #executor = ProcessPool(nodes=self.np)
             #results = executor.map(self.get_AijR_rhoR, self.contour.path)
             results = p_map(self.get_AijR_rhoR,
-                            self.contour.path, num_cpus=self.np)
+                            self.contour.path,
+                            num_cpus=self.np)
         else:
-            results = map(self.get_AijR_rhoR, tqdm(
-                self.contour.path, total=npole))
+            results = map(self.get_AijR_rhoR,
+                          tqdm(self.contour.path, total=npole))
 
         for i, result in enumerate(results):
             for iR, R in enumerate(self.R_ijatom_dict):
@@ -678,8 +681,9 @@ class ExchangeNCL(Exchange):
                         AijRs[(R, iatom, jatom)].append(result[0][R, iatom,
                                                                   jatom])
                         if self.orb_decomposition:
-                            AijRs_orb[(R, iatom, jatom)].append(result[1][R, iatom,
-                                                                          jatom])
+                            AijRs_orb[(R, iatom,
+                                       jatom)].append(result[1][R, iatom,
+                                                                jatom])
 
                     else:
                         AijRs[(R, iatom, jatom)] = []
@@ -687,8 +691,9 @@ class ExchangeNCL(Exchange):
                                                                   jatom])
                         if self.orb_decomposition:
                             AijRs_orb[(R, iatom, jatom)] = []
-                            AijRs_orb[(R, iatom, jatom)].append(result[1][R, iatom,
-                                                                          jatom])
+                            AijRs_orb[(R, iatom,
+                                       jatom)].append(result[1][R, iatom,
+                                                                jatom])
             rhoRs.append(result[2])
         if self.np > 1:
             # executor.close()
@@ -753,6 +758,7 @@ class ExchangeNCL(Exchange):
 
 
 class ExchangeCL(ExchangeNCL):
+
     def set_tbmodels(self, tbmodel):
         """
         only difference is a colinear tag.
